Tree

Struct Tree 

pub struct Tree<V> { /* private fields */ }

Implementations

Source

impl Tree<()>

Source

impl<V: Default> Tree<V>

pub fn with_default() -> Self

Source

impl<V> Tree<V>

pub fn new(root: V) -> Self

pub fn clear(&mut self)

pub fn is_leaf(&self, index: NodeIndex) -> bool

pub fn is_non_leaf(&self, index: NodeIndex) -> bool

pub fn parent(&self, index: NodeIndex) -> Option<NodeIndex>

pub fn get(&self, index: NodeIndex) -> Option<&V>

pub fn get_mut(&mut self, index: NodeIndex) -> Option<&mut V>

pub fn traverse_from<F, R>(&self, from: NodeIndex, f: F) -> Option<R>
where F: FnMut(&V) -> Option<R>,

Traverses sub-tree starting with the from node in a DFS way.

Panics

Panics if the given node index is out of bounds.

pub fn next_index(&self) -> NodeIndex

pub fn insert(&mut self, parent: NodeIndex, value: V) -> Option<NodeIndex>

Inserts a node with the given value under the parent node, then returns true if the operation was successful.

pub fn take(&mut self, index: NodeIndex) -> Option<V>

Takes out the value at the given index.

Other indices are not affected by this operation, but the whole sub-tree starting with the node will be removed.