Const

Enum Const 

pub enum Const {
    Free {
        ptr_const: NonNull<ItemConst>,
        vis_node: NodeIndex,
        tid: TypeId,
    },
    Inher {
        ptr_const: NonNull<ImplItemConst>,
        vis_node: NodeIndex,
        tid: TypeId,
    },
    TraitDefault {
        ptr_const: NonNull<TraitItemConst>,
        vis_node: NodeIndex,
        tid: TypeId,
    },
    TraitImpl {
        ptr_const: NonNull<ImplItemConst>,
        vis_node: NodeIndex,
        tid: TypeId,
    },
}

Variants



Free

Fields

ptr_const: NonNull<ItemConst>

Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndex

Refer to the module documentation.

tid: TypeId

Type of this item.



Inher

Fields

ptr_const: NonNull<ImplItemConst>

Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndex

Refer to the module documentation.

tid: TypeId

Type of this item.



TraitDefault

Fields

ptr_const: NonNull<TraitItemConst>

Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndex

Refer to the module documentation.

tid: TypeId

Type of this item.



TraitImpl

Fields

ptr_const: NonNull<ImplItemConst>

Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndex

Refer to the module documentation.

tid: TypeId

Type of this item.

Implementations

Source

impl Const

pub fn ptr_syn(&self) -> ConstPtr

pub fn syn_id(&self) -> SynId

pub fn syn_type(&self) -> &Type

pub fn syn_expr(&self) -> Option<&Expr>

pub fn vis_node(&self) -> NodeIndex

pub fn type_id(&self) -> TypeId