pub struct OnceQueue<T: Identify> { /* private fields */ }Implementations
Sourceimpl<T: Identify> OnceQueue<T>
impl<T: Identify> OnceQueue<T>
pub fn new() -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn iter(&self) -> Iter<'_, T>
pub fn is_pushable(&self, value: &T) -> bool
pub fn count(&self, value: &T) -> u32
Sourcepub fn push_back(&mut self, value: T) -> Result<(), T>
pub fn push_back(&mut self, value: T) -> Result<(), T>
Appends the value at the end of the queue if the queue has not seen the value before.
If the queue has seen the value, then returns it within error.
Sourcepub fn push_front(&mut self, value: T) -> Result<(), T>
pub fn push_front(&mut self, value: T) -> Result<(), T>
Appends the value at the beginning of the queue if the queue has not seen the value before.
If the queue has seen the value, then returns it within error.
Sourcepub fn push_back_force(&mut self, value: T)
pub fn push_back_force(&mut self, value: T)
Appends the value at the end of the queue regardless of whether the queue has seen the value before.
Sourcepub fn push_front_force(&mut self, value: T)
pub fn push_front_force(&mut self, value: T)
Appends the value at the beginning of the queue regardless of whether the queue has seen the value before.