pub struct Tree<V> { /* private fields */ }Implementations
Sourceimpl<V> Tree<V>
impl<V> Tree<V>
pub fn new(root: V) -> Self
pub fn clear(&mut self)
pub fn is_leaf(&self, index: NodeIndex) -> bool
pub fn is_non_leaf(&self, index: NodeIndex) -> bool
pub fn parent(&self, index: NodeIndex) -> Option<NodeIndex>
pub fn get(&self, index: NodeIndex) -> Option<&V>
pub fn get_mut(&mut self, index: NodeIndex) -> Option<&mut V>
Sourcepub fn traverse_from<F, R>(&self, from: NodeIndex, f: F) -> Option<R>
pub fn traverse_from<F, R>(&self, from: NodeIndex, f: F) -> Option<R>
Traverses sub-tree starting with the from node in a DFS way.
Panics
Panics if the given node index is out of bounds.
pub fn next_index(&self) -> NodeIndex