pub enum Const {
Free {
ptr_const: NonNull<ItemConst>,
vis_node: NodeIndex,
tid: TypeId,
},
Inher {
ptr_const: NonNull<ImplItemConst>,
vis_node: NodeIndex,
tid: TypeId,
},
TraitDefault {
ptr_const: NonNull<TraitItemConst>,
vis_node: NodeIndex,
tid: TypeId,
},
TraitImpl {
ptr_const: NonNull<ImplItemConst>,
vis_node: NodeIndex,
tid: TypeId,
},
}Variants
Free
Fields

vis_node: NodeIndexRefer to the module documentation.
Inher
Fields

ptr_const: NonNull<ImplItemConst>Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndexRefer to the module documentation.
TraitDefault
Fields

ptr_const: NonNull<TraitItemConst>Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndexRefer to the module documentation.
TraitImpl
Fields

ptr_const: NonNull<ImplItemConst>Read-only pointer to a syntax tree node that never changes.

vis_node: NodeIndexRefer to the module documentation.
Implementations